@@ -21,7 +21,7 @@ _ALLOWED_FILE_TYPES = ['.bin', '.dat', '.bat', '.raw']  # For binary data
 
 class SettingsBox(QtWidgets.QGroupBox):
     settingsUpdated = QtCore.Signal()
-    previewProbe = QtCore.Signal(object)
+    previewProbe = QtCore.Signal(object, object)
     dataChanged = QtCore.Signal()
 
     def __init__(self, parent):
@@ -474,9 +474,10 @@ class SettingsBox(QtWidgets.QGroupBox):
         if not self.check_valid_binary_path(self.data_file_path):
             return False
 
-        none_allowed = ['dmin', 'nt0min']
+        none_allowed = ['dmin', 'nt0min', 'max_channel_distance', 'x_centers']
         for k, v in self.settings.items():
             if v is None and k not in none_allowed:
+                print(f'`None` not allowed for parameter {k}.')
                 return False
         return True
     
@@ -500,9 +501,17 @@ class SettingsBox(QtWidgets.QGroupBox):
             else:
                 self.settingsUpdated.emit()
 
+    def get_probe_template_args(self):
+        epw = self.extra_parameters_window
+        template_args = [
+            epw.nearest_chans, epw.dmin, epw.dminx, 
+            epw.max_channel_distance, epw.x_centers, self.gui.device
+            ]
+        return template_args
+
     @QtCore.Slot()
     def show_probe_layout(self):
-        self.previewProbe.emit(self.probe_layout)
+        self.previewProbe.emit(self.probe_layout, self.get_probe_template_args())
 
     @QtCore.Slot(str)
     def on_probe_layout_selected(self, name):
@@ -664,6 +673,12 @@ class SettingsBox(QtWidgets.QGroupBox):
         self.probe_layout_selector.addItems([""] + probes_list + ["[new]", "other..."])
         self._probes = probes_list
 
+    def clear_probe_selection(self):
+        self.probe_layout_selector.setCurrentIndex(0)
+        self.gui.qt_settings.setValue('probe_layout', None)
+        self.gui.qt_settings.setValue('probe_name', None)
+        self.disable_preview_probe()
+
     def populate_dtype_selector(self):
         self.dtype_selector.clear()
         supported_dtypes = BinaryRWFile.supported_dtypes
@@ -718,11 +733,8 @@ class SettingsBox(QtWidgets.QGroupBox):
         self.results_directory_input.clear()
         self.results_directory_path = None
         self.gui.qt_settings.setValue('results_dir', None)
-        self.probe_layout_selector.setCurrentIndex(0)
-        self.gui.qt_settings.setValue('probe_layout', None)
-        self.gui.qt_settings.setValue('probe_name', None)
+        self.clear_probe_selection()
         self.set_default_field_values()
-        self.disable_preview_probe()
         self.disable_load()
 
     def check_load(self):
