@@ -104,9 +104,6 @@ def run_kilosort(settings, probe=None, probe_name=None, filename=None,
             )
     settings = {**DEFAULT_SETTINGS, **settings}
 
-    if settings['nt0min'] is None:
-        settings['nt0min'] = int(20 * settings['nt']/61)
-
     if data_dtype is None:
         print("Interpreting binary file as default dtype='int16'. If data was "
                 "saved in a different format, specify `data_dtype`.")
@@ -126,6 +123,12 @@ def run_kilosort(settings, probe=None, probe_name=None, filename=None,
         set_files(settings, filename, probe, probe_name, data_dir, results_dir)
     ops = initialize_ops(settings, probe, data_dtype, do_CAR, invert_sign, device)
 
+    if probe['chanMap'].max() >= settings['n_chan_bin']:
+        raise ValueError(
+            f'Largest value of chanMap exceeds channel count of data, '
+             'make sure chanMap is 0-indexed.'
+        )
+
     # Set preprocessing and drift correction parameters
     ops = compute_preprocessing(ops, device, tic0=tic0, file_object=file_object)
     np.random.seed(1)
@@ -145,11 +148,12 @@ def run_kilosort(settings, probe=None, probe_name=None, filename=None,
                                  progress_bar=progress_bar)
     clu, Wall = cluster_spikes(st, tF, ops, device, bfile, tic0=tic0,
                                progress_bar=progress_bar)
-    ops, similar_templates, is_ref, est_contam_rate = \
+    ops, similar_templates, is_ref, est_contam_rate, kept_spikes = \
         save_sorting(ops, results_dir, st, clu, tF, Wall, bfile.imin, tic0,
                      save_extra_vars=save_extra_vars)
 
-    return ops, st, clu, tF, Wall, similar_templates, is_ref, est_contam_rate
+    return ops, st, clu, tF, Wall, similar_templates, \
+           is_ref, est_contam_rate, kept_spikes
 
 
 def set_files(settings, filename, probe, probe_name, data_dir, results_dir):
@@ -202,6 +206,8 @@ def set_files(settings, filename, probe, probe_name, data_dir, results_dir):
 def initialize_ops(settings, probe, data_dtype, do_CAR, invert_sign, device) -> dict:
     """Package settings and probe information into a single `ops` dictionary."""
 
+    if settings['nt0min'] is None:
+        settings['nt0min'] = int(20 * settings['nt']/61)
     # TODO: Clean this up during refactor. Lots of confusing duplication here.
     ops = settings  
     ops['settings'] = settings 
@@ -470,7 +476,8 @@ def save_sorting(ops, results_dir, st, clu, tF, Wall, imin, tic0=np.nan,
     """
 
     print('\nSaving to phy and computing refractory periods')
-    results_dir, similar_templates, is_ref, est_contam_rate = io.save_to_phy(
+    results_dir, similar_templates, is_ref, est_contam_rate, kept_spikes = \
+        io.save_to_phy(
             st, clu, tF, Wall, ops['probe'], ops, imin, results_dir=results_dir,
             data_dtype=ops['data_dtype'], save_extra_vars=save_extra_vars
             )
@@ -487,7 +494,7 @@ def save_sorting(ops, results_dir, st, clu, tF, Wall, imin, tic0=np.nan,
 
     io.save_ops(ops, results_dir)
 
-    return ops, similar_templates, is_ref, est_contam_rate
+    return ops, similar_templates, is_ref, est_contam_rate, kept_spikes
 
 
 def load_sorting(results_dir, device=None, load_extra_vars=False):
